==> rearm-2.4.9%2B1.21.1-fabric-sources.jar: me/pajic/rearm/ability/CripplingThrowAbility.java <==
package me.pajic.rearm.ability;

import me.pajic.rearm.ReArm;
import me.pajic.rearm.enchantment.ReArmEnchantments;
import me.pajic.rearm.projectile.ThrownAxe;
import net.minecraft.class_1268;
import net.minecraft.class_1271;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1311;
import net.minecraft.class_1657;
import net.minecraft.class_1665;
import net.minecraft.class_1799;
import net.minecraft.class_1890;
import net.minecraft.class_1937;
import net.minecraft.class_2960;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_4844;
import net.minecraft.class_5134;
import net.minecraft.class_7924;
import net.minecraft.class_8710;
import net.minecraft.class_9129;
import net.minecraft.class_9139;
import org.jetbrains.annotations.NotNull;
import java.util.HashSet;
import java.util.Set;
import java.util.UUID;

public class CripplingThrowAbility {

    public static final class_2960 RECALL_AXE = ReArm.id("recall_axe");

    public record C2SUpdatePlayerRecallCondition(UUID activePlayerUUID) implements class_8710 {
        public static final class_9154<C2SUpdatePlayerRecallCondition> TYPE = new class_9154<>(RECALL_AXE);
        public static final class_9139<class_9129, C2SUpdatePlayerRecallCondition> CODEC = class_9139.method_56434(
                class_4844.field_48453, C2SUpdatePlayerRecallCondition::activePlayerUUID,
                C2SUpdatePlayerRecallCondition::new
        );

        @Override
        public @NotNull class_9154<? extends class_8710> method_56479() {
            return TYPE;
        }
    }

    public static final class_1299<ThrownAxe> AXE = class_1299.class_1300.<ThrownAxe>method_5903(ThrownAxe::new, class_1311.field_17715)
			.method_17687(0.5F, 0.5F)
			.method_55687(0.13F)
			.method_27300(1)
			.build(
					//? if fabric && > 1.21.1 || neoforge && > 1.21.1
					/*ResourceKey.create(Registries.ENTITY_TYPE, ReArm.id("axe"))*/
					//? if neoforge && 1.21.1
					/*"axe"*/
			);

    public static final Set<UUID> recallSignals = new HashSet<>();

    public static /*? if 1.21.1 {*/class_1271<class_1799>/*?} else {*//*InteractionResult*//*?}*/ useAxe(
            class_1937 level, class_1657 player, class_1268 usedHand, class_1799 stack
    ) {
        int cripplingThrowLevel = class_1890.method_8225(
                //? if 1.21.1
                level.method_30349().method_30530(class_7924.field_41265).method_40290(ReArmEnchantments.CRIPPLING_THROW),
                //? if > 1.21.1
                /*level.registryAccess().lookupOrThrow(Registries.ENCHANTMENT).getOrThrow(ReArmEnchantments.CRIPPLING_THROW),*/
                stack
        );
        if (cripplingThrowLevel > 0) {
            if (stack.method_7919() >= stack.method_7936() - 1) {
                //? if 1.21.1
                return class_1271.method_22431(stack);
                //? if > 1.21.1
                /*return InteractionResult.FAIL;*/
            } else {
                player.method_6019(usedHand);
                //? if 1.21.1
                return class_1271.method_22428(stack);
                //? if > 1.21.1
                /*return InteractionResult.CONSUME;*/
            }
        }
        //? if 1.21.1
        return class_1271.method_22431(stack);
        //? if > 1.21.1
        /*return InteractionResult.FAIL;*/
    }

    public static void throwAxe(class_1799 stack, class_1937 level, class_1309 livingEntity, int timeCharged, int useDuration) {
        if (livingEntity instanceof class_1657 player) {
            if (useDuration - timeCharged >= 10 && !(stack.method_7919() >= stack.method_7936() - 1) && !level.method_8608()) {
                stack.method_7970(2, player,
                        /*? if 1.21.1 {*/class_1657.method_56079(player.method_6058())/*?} else {*//*player.getUsedItemHand()*//*?}*/
                );
                ThrownAxe thrownAxe = new ThrownAxe(
                        level, player, stack,
                        (float) player.method_45325(class_5134.field_23721),
                        player.method_6058()
                );
                thrownAxe.method_24919(player, player.method_36455(), player.method_36454(), 0.0F, 2.5F, 1.0F);
                if (player.method_56992()) thrownAxe.field_7572 = class_1665.class_1666.field_7594;
                level.method_8649(thrownAxe);
                level.method_43129(null, thrownAxe, class_3417.field_15001.comp_349(), class_3419.field_15248, 1.0F, 1.0F);
                if (!player.method_56992()) {
                    player.method_31548().method_7378(stack);
                }
            }
        }
    }
}

==> rearm-2.4.11%2B1.21.10-fabric-sources.jar: me/pajic/rearm/ability/CripplingThrowAbility.java <==
package me.pajic.rearm.ability;

import me.pajic.rearm.ReArm;
import me.pajic.rearm.enchantment.ReArmEnchantments;
import me.pajic.rearm.projectile.ThrownAxe;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1311;
import net.minecraft.class_1657;
import net.minecraft.class_1665;
import net.minecraft.class_1799;
import net.minecraft.class_1890;
import net.minecraft.class_1937;
import net.minecraft.class_2960;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_4844;
import net.minecraft.class_5134;
import net.minecraft.class_5321;
import net.minecraft.class_7924;
import net.minecraft.class_8710;
import net.minecraft.class_9129;
import net.minecraft.class_9139;
import org.jetbrains.annotations.NotNull;
import java.util.HashSet;
import java.util.Set;
import java.util.UUID;

public class CripplingThrowAbility {

    public static final class_2960 RECALL_AXE = ReArm.id("recall_axe");

    public record C2SUpdatePlayerRecallCondition(UUID activePlayerUUID) implements class_8710 {
        public static final class_9154<C2SUpdatePlayerRecallCondition> TYPE = new class_9154<>(RECALL_AXE);
        public static final class_9139<class_9129, C2SUpdatePlayerRecallCondition> CODEC = class_9139.method_56434(
                class_4844.field_48453, C2SUpdatePlayerRecallCondition::activePlayerUUID,
                C2SUpdatePlayerRecallCondition::new
        );

        @Override
        public @NotNull class_9154<? extends class_8710> method_56479() {
            return TYPE;
        }
    }

    public static final class_1299<ThrownAxe> AXE = class_1299.class_1300.<ThrownAxe>method_5903(ThrownAxe::new, class_1311.field_17715)
			.method_17687(0.5F, 0.5F)
			.method_55687(0.13F)
			.method_27300(1)
			.method_5905(
					//? if fabric && > 1.21.1 || neoforge && > 1.21.1
					class_5321.method_29179(class_7924.field_41266, ReArm.id("axe"))
					//? if neoforge && 1.21.1
					/*"axe"*/
			);

    public static final Set<UUID> recallSignals = new HashSet<>();

    public static /*? if 1.21.1 {*//*InteractionResultHolder<ItemStack>*//*?} else {*/class_1269/*?}*/ useAxe(
            class_1937 level, class_1657 player, class_1268 usedHand, class_1799 stack
    ) {
        int cripplingThrowLevel = class_1890.method_8225(
                //? if 1.21.1
                /*level.registryAccess().registryOrThrow(Registries.ENCHANTMENT).getHolderOrThrow(ReArmEnchantments.CRIPPLING_THROW),*/
                //? if > 1.21.1
                level.method_30349().method_30530(class_7924.field_41265).method_46747(ReArmEnchantments.CRIPPLING_THROW),
                stack
        );
        if (cripplingThrowLevel > 0) {
            if (stack.method_7919() >= stack.method_7936() - 1) {
                //? if 1.21.1
                /*return InteractionResultHolder.fail(stack);*/
                //? if > 1.21.1
                return class_1269.field_5814;
            } else {
                player.method_6019(usedHand);
                //? if 1.21.1
                /*return InteractionResultHolder.consume(stack);*/
                //? if > 1.21.1
                return class_1269.field_21466;
            }
        }
        //? if 1.21.1
        /*return InteractionResultHolder.fail(stack);*/
        //? if > 1.21.1
        return class_1269.field_5814;
    }

    public static void throwAxe(class_1799 stack, class_1937 level, class_1309 livingEntity, int timeCharged, int useDuration) {
        if (livingEntity instanceof class_1657 player) {
            if (useDuration - timeCharged >= 10 && !(stack.method_7919() >= stack.method_7936() - 1) && !level.method_8608()) {
                stack.method_71012(2, player,
                        /*? if 1.21.1 {*//*Player.getSlotForHand(player.getUsedItemHand())*//*?} else {*/player.method_6058()/*?}*/
                );
                ThrownAxe thrownAxe = new ThrownAxe(
                        level, player, stack,
                        (float) player.method_45325(class_5134.field_23721),
                        player.method_6058()
                );
                thrownAxe.method_24919(player, player.method_36455(), player.method_36454(), 0.0F, 2.5F, 1.0F);
                if (player.method_56992()) thrownAxe.field_7572 = class_1665.class_1666.field_7594;
                level.method_8649(thrownAxe);
                level.method_43129(null, thrownAxe, class_3417.field_15001.comp_349(), class_3419.field_15248, 1.0F, 1.0F);
                if (!player.method_56992()) {
                    player.method_31548().method_7378(stack);
                }
            }
        }
    }
}
